What is TOPSIS:  
Technique for Order Preference by Similarity to Ideal Solution (TOPSIS) originated in the 1980s as a multi-criteria decision making method. TOPSIS chooses the alternative of shortest Euclidean distance from the ideal solution, and greatest distance from the negative-ideal solution. More

How to use this package:  
TOPSIS-Jatin-101866020 can be run as in the following example:

In Command Prompt:  
>> topsis-jatin-101866020 data.csv "1,1,1,1" "+,+,-,+" result.csv